# air-convert

![PyPI version](https://img.shields.io/pypi/v/air-convert.svg)
[![Documentation Status](https://readthedocs.org/projects/air-convert/badge/?version=latest)](https://air-convert.readthedocs.io/en/latest/?version=latest)

Utilities fong plan HTML to Air

* PyPI package: https://pypi.org/project/air-convert/
* Free software: MIT License
* Documentation: https://air-convert.readthedocs.io.

## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyfeldroy/cookiecutter) and the [audreyfeldroy/cookiecutter-pypackage](https://github.com/audreyfeldroy/cookiecutter-pypackage) project template.
